---
title: <span class="badge builder"></span> QueryEditorOperator
---
# <span class="badge builder"></span> QueryEditorOperator

## Constructor

```python
QueryEditorOperator()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> cloudwatch.QueryEditorOperator
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> value

```python
def value(value: typing.Union[str, bool, int, list[cloudwatch.QueryEditorOperatorType]]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [QueryEditorOperator](./object-QueryEditorOperator.md)
